@@ -4,9 +4,9 @@ library(gmapsdistance)
 # Athens, Greece. This example shows that the function is able to handle
 # LAT-LONG coordinates and a Google Maps API Key
 
-results = gmapsdistance("38.1621328+24.0029257",
-                      "37.9908372+23.7383394",
-                      "walking")
+results = gmapsdistance(origin = "38.1621328+24.0029257",
+                        destination = "37.9908372+23.7383394",
+                        mode = "walking")
 results$Time
 results$Distance
 results$Status
